@@ -267,7 +267,7 @@ class Chip_TMC5031(i2c.I2CChip):
         second = 1
     
     def __init__(self, bus_addr: int, **kwargs):
-        super().__init__(bus_addr, offset_mode=self.I2COffsetMode.NoOffset, auto_lock=True, **kwargs)
+        super().__init__(bus_addr, offset_mode=i2c.I2COffsetMode.NoOffset, auto_lock=True, **kwargs)
         self._spi_gpio_cache = 0
         self._last_spi_status = 0
 
