@@ -70,6 +70,19 @@ class Spm():
         Fast = 3
         VeryFast = 4
 
+    class ScanAxisRangeModes(enum.IntEnum):
+        Off = 0
+        FullRange = 1
+        ReducedRange = 2
+
+    class XYClosedLoopModes(enum.IntEnum):
+        OpenLoop = 0
+        ClosedLoop = 1
+
+    class ZClosedLoopModes(enum.IntEnum):
+        FixDrive = 0
+        FixPosition = 1
+
     class VideoSource(enum.IntEnum):
         SideView = 0
         TopView = 1
@@ -257,6 +270,10 @@ class Spm():
         Internal = 0
         External = 1
 
+    class ExcitationMode(enum.IntEnum):
+        PiezoElectric = 0
+        PhotoThermal = 1
+
     class User0InputPol(enum.IntEnum):
         Positive = 0
         Negative = 1
