@@ -323,7 +323,9 @@ class StudioScriptContext(StudioScriptInterface):
         return (res_ok, res_val)
 
     def _python_to_lua_str(self, val:str) -> str:
-        cmd_str = val.replace('"', '\\"')
+        cmd_str = val
+        cmd_str = cmd_str.replace('\\', '\\\\')
+        cmd_str = cmd_str.replace('"', '\\"')
         cmd_str = cmd_str.replace("'", "\\'")
         return cmd_str
 
