@@ -83,6 +83,7 @@ class CmdTreeCompiler():
         self._last_error = ""
         self.my_own_path = pathlib.Path(os.path.dirname(os.path.abspath(__file__)))
         self.regex_non_enum_chars = re.compile('[^0-9a-zA-Z]+', flags=re.UNICODE); 
+        self.regex_first_char_a_number = re.compile('\d\w*', flags=re.UNICODE); 
 
     def build_wrapper_class(self, context_name: str, cmd_table) -> bool:
         self.cmd_package_name = g_context_package_name_prefix + context_name 
@@ -179,7 +180,10 @@ class CmdTreeCompiler():
         return "enum" in prop_elements
         
     def _convert_enum_str_to_enum_class_name(self, enum_name:str) -> str:
-        class_name = self.regex_non_enum_chars.sub('_', enum_name)
+        class_name = enum_name
+        class_name = self.regex_non_enum_chars.sub('_', class_name)
+        if self.regex_first_char_a_number.match(class_name):
+            class_name =  "num_" + class_name
         return class_name
 
     def _get_studio_property_elements(self, prop_table) -> dict[str, str]:
@@ -334,5 +338,3 @@ class CmdTreeCompiler():
                     new_class_name = str(class_name+item_name.capitalize())
                     new_lua_tree_name = str(lua_tree_name+"."+item_name)
                     self._write_cmd_tree_node(item_value, new_class_name, new_lua_tree_name)
-
-
