@@ -272,8 +272,8 @@ class _ModZControlOutput(_ModulationOutput):
         super().__init__()
         self._pid_control = lowlevel.ZControllerEx()
         try:
-            self._old_value = self._pid_control.set_point_modulation_enable.value
-            self._pid_control.set_point_modulation_enable.value = (
+            self._old_value = self._pid_control.output_modulation_enable.value
+            self._pid_control.output_modulation_enable.value = (
                 self._pid_control.Enable.Enabled)
             self.new_style = True
         except:
@@ -284,30 +284,30 @@ class _ModZControlOutput(_ModulationOutput):
 
     def __del__(self):
         if self.new_style:
-            self._pid_control.set_point_modulation_enable.value = self._old_value
+            self._pid_control.output_modulation_enable.value = self._old_value
         else:
             self._pid_control.select_sweep.value = self._old_value
         super().__del__()
 
 class FrequencySweepOutput(enum.Enum):
     """Enumeration for the modulation output selection"""
-    Normal_Excitation = enum.auto(),           
-    FastUser_OutB = enum.auto(),           
-    TipVoltage_UserOutA = enum.auto(),           
-    UserOut1_UserC = enum.auto(),           
-    UserOut2_UserA = enum.auto(),           
-    UserOut3_Monitor1 = enum.auto(),           
-    UserOut4_Monitor2 = enum.auto(),           
-    PositionX = enum.auto(),           
-    PositionY = enum.auto(),           
-    PositionZ = enum.auto(),           
-    ModOutZ = enum.auto(),           
-    ModXControlSet = enum.auto(),           
-    ModYControlSet = enum.auto(),           
-    ModZControlSet = enum.auto(),           
-    ModZOutput = enum.auto()
+    Normal_Excitation = enum.auto(),
+    FastUser_OutB = enum.auto(),
+    TipVoltage_UserOutA = enum.auto(),
+    UserOut1_UserC = enum.auto(),
+    UserOut2_UserA = enum.auto(),
+    UserOut3_Monitor1 = enum.auto(),
+    UserOut4_Monitor2 = enum.auto(),
+    PositionX = enum.auto(),
+    PositionY = enum.auto(),
+    PositionZ = enum.auto(),
+    ModOutZ = enum.auto(),
+    ModXControlSet = enum.auto(),
+    ModYControlSet = enum.auto(),
+    ModZControlSet = enum.auto(),
+    ModZControlOutput = enum.auto()
 
-class InputSource(enum.Enum): 
+class InputSource(enum.Enum):
     Deflection = enum.auto(),
     Fast2_CX = enum.auto(),
     Fast_User_CX = enum.auto(),
@@ -336,13 +336,13 @@ class Bandwidths(enum.IntEnum):
     Hz_23 = 0,
     Hz_45 = 1,
     Hz_90 = 2,
-    Hz_180 = 3, 
+    Hz_180 = 3,
     Hz_360 = 4,
-    Hz_740 = 5, 
+    Hz_740 = 5,
     Hz_1500 = 6,
     Hz_3000 = 7,
-    Hz_6000 = 8, 
-    Hz_12k = 9, 
+    Hz_6000 = 8,
+    Hz_12k = 9,
     Hz_24k= 10,
     Hz_48k = 11,
     Hz_100k = 12,
@@ -368,7 +368,7 @@ class FrequencySweep():
         FrequencySweepOutput.ModXControlSet.name: _ModXControlSet,
         FrequencySweepOutput.ModYControlSet.name: _ModYControlSet,
         FrequencySweepOutput.ModZControlSet.name: _ModZControlSet,
-        FrequencySweepOutput.ModZOutput.name: _ModZControlOutput
+        FrequencySweepOutput.ModZControlOutput.name: _ModZControlOutput
         }
 
     input_sources_names: dict[InputSource, str] = {
@@ -393,45 +393,45 @@ class FrequencySweep():
     }
 
     bandwidths_names = {
-        Bandwidths.Hz_23: "23Hz", 
-        Bandwidths.Hz_45:"45Hz", 
-        Bandwidths.Hz_90:"90Hz", 
-        Bandwidths.Hz_180:"180Hz", 
-        Bandwidths.Hz_360:"360Hz", 
-        Bandwidths.Hz_740:"740Hz", 
+        Bandwidths.Hz_23: "23Hz",
+        Bandwidths.Hz_45:"45Hz",
+        Bandwidths.Hz_90:"90Hz",
+        Bandwidths.Hz_180:"180Hz",
+        Bandwidths.Hz_360:"360Hz",
+        Bandwidths.Hz_740:"740Hz",
         Bandwidths.Hz_1500:"1500Hz",
-        Bandwidths.Hz_3000:"3kHz", 
-        Bandwidths.Hz_6000:"6kHz", 
-        Bandwidths.Hz_12k:"12kHz", 
-        Bandwidths.Hz_24k:"23kHz", 
-        Bandwidths.Hz_48k:"45kHz", 
-        Bandwidths.Hz_100k:"100kHz", 
+        Bandwidths.Hz_3000:"3kHz",
+        Bandwidths.Hz_6000:"6kHz",
+        Bandwidths.Hz_12k:"12kHz",
+        Bandwidths.Hz_24k:"23kHz",
+        Bandwidths.Hz_48k:"45kHz",
+        Bandwidths.Hz_100k:"100kHz",
         Bandwidths.Hz_230k:"230kHz",
         Bandwidths.Hz_500k:"500kHz"
     }
 
     input_ranges_names: dict[InputRanges,str] = {
-        InputRanges.Full:           "Full", 
-        InputRanges.OneOverFour:    "1/4", 
+        InputRanges.Full:           "Full",
+        InputRanges.OneOverFour:    "1/4",
         InputRanges.OneOverSixteen: "1/16"
     }
 
     output_names: dict[FrequencySweepOutput, str] = {
-        FrequencySweepOutput.Normal_Excitation:"Normal Excitation", 
-        FrequencySweepOutput.FastUser_OutB: "Fast User / Out B", 
+        FrequencySweepOutput.Normal_Excitation:"Normal Excitation",
+        FrequencySweepOutput.FastUser_OutB: "Fast User / Out B",
         FrequencySweepOutput.TipVoltage_UserOutA:"Tip Voltage / User Out A",
-        FrequencySweepOutput.UserOut1_UserC:"User 1 / C", 
-        FrequencySweepOutput.UserOut2_UserA:"User 2 / A", 
-        FrequencySweepOutput.UserOut3_Monitor1:"User 3 / Monitor 1", 
+        FrequencySweepOutput.UserOut1_UserC:"User 1 / C",
+        FrequencySweepOutput.UserOut2_UserA:"User 2 / A",
+        FrequencySweepOutput.UserOut3_Monitor1:"User 3 / Monitor 1",
         FrequencySweepOutput.UserOut4_Monitor2:"User 4 / Monitor 2",
-        FrequencySweepOutput.PositionX:"X Position", 
-        FrequencySweepOutput.PositionY:"Y Position", 
-        FrequencySweepOutput.PositionZ:"PosOutZ", 
-        FrequencySweepOutput.ModOutZ:"ModOutZ", 
+        FrequencySweepOutput.PositionX:"X Position",
+        FrequencySweepOutput.PositionY:"Y Position",
+        FrequencySweepOutput.PositionZ:"PosOutZ",
+        FrequencySweepOutput.ModOutZ:"ModOutZ",
         FrequencySweepOutput.ModXControlSet:"ModXControlSet",
-        FrequencySweepOutput.ModYControlSet:"ModYControlSet", 
-        FrequencySweepOutput.ModZControlSet:"ModZControlSet", 
-        FrequencySweepOutput.ModZOutput:"ModZControlOutput"
+        FrequencySweepOutput.ModYControlSet:"ModYControlSet",
+        FrequencySweepOutput.ModZControlSet:"ModZControlSet",
+        FrequencySweepOutput.ModZControlOutput:"ModZControlOutput"
     }
 
     def __init__(self, spm: spm.Spm):
@@ -442,6 +442,7 @@ class FrequencySweep():
         self.data_channel_phase = 3
         self._spm = spm
         self._ll = spm.lowlevel
+        self._internal_transfer_time = 5.0
 
         self._analyzer = self._ll.SignalAnalyzer(spm.lowlevel.SignalAnalyzer.Instance.INST2)
         self._system_infra = self._ll.SystemInfra()
@@ -517,8 +518,8 @@ class FrequencySweep():
         new_data = document.DataGetByPos(group, self.data_channel_amplitude)
         assert new_data is not None, "No data!"
         data_line:str = new_data.GetLine(0, spm.Spm.DataFilter.RAW, spm.Spm.DataConversion.Physical)
-        # in some countries numbers have ',' as dot but float(str) has problems with this localisation
-        usa_style_data_line = data_line.replace(",", ".") 
+        # in some countries numbers have ',' as dot but float(str) has problems with this localization
+        usa_style_data_line = data_line.replace(",", ".")
         amplitude = np.array(usa_style_data_line.split(";")).astype(float)
 
         new_data = document.DataGetByPos(group, self.data_channel_phase)
@@ -560,7 +561,7 @@ class FrequencySweep():
         limited_step_time = max(step_time, 0.01)
 
         generator = self._frequency_sweep_generator
-        generator.lusig_analyzer_inst_no.value = ( 
+        generator.lusig_analyzer_inst_no.value = (
             generator.LUSigAnalyzerInstNo.INST2)
 
         generator.start_frequency.value = start_frequency
@@ -573,16 +574,19 @@ class FrequencySweep():
         generator.sweep_amplitude.value = amplitude
 
         self.start_time = time.time()
+        self.start_frequency = start_frequency
+        self.end_frequency = end_frequency
         self.is_busy = True
         generator.start_frequency_sweep()
 
-        return limited_step_time * points + 2 * settle_time + 16.0
+        return limited_step_time*points + 2*settle_time + self._internal_transfer_time/2
 
     def _finish(self):
         """Stop FrequencySweep and capture measured data into new document"""
         self._frequency_sweep_generator.user_abort()
-        time.sleep(0.01)
+        time.sleep(0.1)
         self._spm.application.OperatingMode.CaptureFreqSearchChart
+        time.sleep(self._internal_transfer_time/2)
         self.is_busy = False
 
     def _to_hz(self, mixer_bw_sel: Bandwidths) -> float:
@@ -594,9 +598,9 @@ class FrequencySweep():
     def start_execute(
             self, start_frequency: float, end_frequency: float, frequency_step: float,
             sweep_amplitude: float,
-            input_source: InputSource,      
-            input_range: InputRanges,       
-            mixer_bw_select: Bandwidths,   
+            input_source: InputSource,
+            input_range: InputRanges,
+            mixer_bw_select: Bandwidths,
             reference_phase: float, output: FrequencySweepOutput) -> float:
         """Prepares and executes the Frequency Sweep.
 
@@ -619,7 +623,7 @@ class FrequencySweep():
         reference_phase : float
             Phase shift of the reference output relative to the internal reference [°]
         output :  FrequencySweepOutput
-            Selects the output 
+            Selects the output
 
         Returns
         ----------
@@ -639,23 +643,22 @@ class FrequencySweep():
 
         # activate output for modulation
         self.output_setup = self.Output[output.name](self._ll)
-        
+
         self.measure_time = self._start(
             start_frequency, end_frequency, points, step_time, settle_time,
             float(sweep_amplitude) * (self._analyzer.current_reference_amplitude.value_max)
         )
-
         return self.measure_time
 
     def finish_execution(self) -> tuple[np.ndarray, np.ndarray]:
         """ cleanup freq execution and extract data
-        
+
         result
         -------
             two dimensional array with measured data (complex measurement data, frequency array)
         """
         self._finish()
-        
+
         # cleanup and restore original setting of output
         del self.output_setup
         self.output_setup = None
@@ -663,21 +666,25 @@ class FrequencySweep():
         return self._get_active_data()
 
     def is_executing(self) -> bool:
-        """ Polls the measuring status. 
-        
+        """ Polls the measuring status.
+
         Returns
         -------
         returns True if still measuring. False if finished
-        
+
         """
         if self.is_busy:
             return (time.time() - self.start_time) <= self.measure_time
         return False
 
+    def get_current_sweep_frequency(self) -> float:
+        cur_freq =  self._analyzer.reference_frequency.value
+        return cur_freq
+
     def execute(self, *args, **kwargs):
-        """ Do the freq sweep and wait until sweep is finished. 
+        """ Do the freq sweep and wait until sweep is finished.
         If blocking is not desired, then use the commands start_execute(), is_executing() and finish_execute()
-        
+
         Parameters
         ----------
         See start_execute()
@@ -712,7 +719,7 @@ class FrequencySweep():
         plt.ylabel('Amplitude V')
 
         plt.subplot(2, 1, 2)
-        plt.plot(frequencies, 
+        plt.plot(frequencies,
             np.unwrap(np.angle(complex_transfer, deg=True), discont=180))
         plt.title('2nd Lock-In Phase - Frequency Sweep')
         plt.xlabel('Frequency [Hz]')
@@ -747,7 +754,7 @@ if __name__ == "__main__":
         input_source=InputSource.UserIn1,
         input_range=InputRanges.Full,
         mixer_bw_select=Bandwidths.Hz_360,
-        reference_phase=0.0, 
+        reference_phase=0.0,
         output=FrequencySweepOutput.FastUser_OutB
     )
     my_fs.bode_plot(data[0], data[1])
